"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.definition = void 0;
exports.definition = {
    id: 'beyond-hd-oneurl',
    name: 'Beyond-HD (OneURL)',
    description: 'This is BeyondHD using OneURL (for those that have enabled 2FA)',
    language: 'en-US',
    type: 'private',
    encoding: 'UTF-8',
    links: ['https://beyond-hd.me/'],
    caps: {
        categorymappings: [
            { id: '1', cat: 'Movies', desc: 'Movies' },
            { id: '2', cat: 'TV', desc: 'TV' },
        ],
        modes: {
            search: ['q'],
            'tv-search': ['q', 'season', 'ep', 'imdbid'],
            'movie-search': ['q', 'imdbid', 'tmdbid'],
        },
    },
    settings: [
        { name: 'oneurl', type: 'text', label: 'OneURL' },
        {
            name: 'info_oid',
            type: 'info',
            label: 'About One-URL',
            default: "<li>OneURL is found by accessing your Beyond-HD web site,</li><li>hovering over the <b>user icon</b></li><li>and going to <b>My Security</b></li><li>then going to the <b>One URL (OID)</b> tab,</li><li>and if it's not already active, you need to hit <b>Reset One URL</b> to activate it.</li><li>Then use that link here.</li>",
        },
        {
            name: 'sort',
            type: 'select',
            label: 'Sort requested from site',
            default: 'created_at',
            options: {
                created_at: 'created',
                seeders: 'seeders',
                size: 'size',
                name: 'title',
            },
        },
        {
            name: 'type',
            type: 'select',
            label: 'Order requested from site',
            default: 'desc',
            options: { desc: 'desc', asc: 'asc' },
        },
    ],
    login: {
        method: 'oneurl',
        inputs: { oneurl: '{{ .Config.oneurl }}' },
        test: { path: 'torrents' },
    },
    search: {
        paths: [{ path: 'torrents' }],
        inputs: {
            $raw: '{{ range .Categories }}categories[]={{.}}&{{end}}',
            search: '{{ if .Query.IMDBID }}{{ else }}{{ .Keywords }}{{ end }}',
            uploader: '',
            imdb: '{{ .Query.IMDBIDShort }}',
            tmdb: '{{ .Query.TMDBID }}',
            sorting: '{{ .Config.sort }}',
            direction: '{{ .Config.type }}',
            qty: 100,
        },
        rows: {
            selector: 'div.table-torrents > table > tbody > tr[id^="torrentposter"]',
        },
        fields: {
            _category: {
                selector: 'a[href*="/categories/"]',
                optional: true,
                attribute: 'href',
                filters: [{ name: 'regexp', args: '/categories/.*?\\.(\\d+)' }],
            },
            category: {
                text: '{{ if .Result._category }}{{ .Result._category }}{{ else }}1{{ end }}',
            },
            title: { selector: 'a.torrent-name' },
            details: { selector: 'a.torrent-name', attribute: 'href' },
            download: {
                selector: 'a[href*="/download/"]',
                attribute: 'href',
            },
            date: {
                selector: 'td:not(a[href$="/history"]) span.text-orange',
                filters: [{ name: 'timeago' }],
            },
            size: { selector: 'td span.text-blue' },
            seeders: { selector: 'a[href$="/peers"] span.text-green' },
            leechers: { selector: 'a[href$="/peers"] span.text-red' },
            grabs: { selector: 'a[href$="/history"]' },
            imdb: {
                selector: 'a[href*="imdb.com/title/tt"]',
                attribute: 'href',
            },
            tmdbid: {
                selector: 'a[href*="themoviedb.org/movie/"]',
                attribute: 'href',
            },
            downloadvolumefactor: {
                case: {
                    'i[data-original-title="100% Free"]': 0,
                    'i[data-original-title="100% Free (Limited UL)"]': 0,
                    'i[data-original-title="25% Promo"]': 0.75,
                    'i[data-original-title="50% Promo"]': 0.5,
                    'i[data-original-title="75% Promo"]': 0.25,
                    '*': 1,
                },
            },
            uploadvolumefactor: { text: 1 },
        },
    },
    source: 'jackett',
};
