"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.definition = void 0;
exports.definition = {
    id: 'uhdbits',
    name: 'UHDBits',
    description: 'A vietnamese general tracker',
    language: 'en-US',
    type: 'private',
    encoding: 'UTF-8',
    links: ['https://uhdbits.org/'],
    caps: {
        categorymappings: [
            { id: '1', cat: 'Movies', desc: 'Movies' },
            { id: '2', cat: 'Audio', desc: 'Music' },
            { id: '3', cat: 'TV', desc: 'TV' },
        ],
        modes: {
            search: ['q'],
            'tv-search': ['q', 'season', 'ep', 'imdbid'],
            'movie-search': ['q', 'imdbid'],
            'music-search': ['q'],
        },
    },
    settings: [
        { name: 'username', type: 'text', label: 'Username' },
        { name: 'password', type: 'password', label: 'Password' },
        { name: '2facode', type: 'text', label: '2FA code' },
        {
            name: 'info_2fa',
            type: 'info',
            label: 'About 2FA code',
            default: 'Only fill in the <b>2FA code</b> box if you have enabled <b>2FA</b> on the UHDBits Web Site. Otherwise just leave it empty.',
        },
        {
            name: 'freeleech',
            type: 'checkbox',
            label: 'Search freeleech only',
            default: false,
        },
        {
            name: 'sort',
            type: 'select',
            label: 'Sort requested from site',
            default: 'time',
            options: { time: 'created', seeders: 'seeders', size: 'size' },
        },
        {
            name: 'type',
            type: 'select',
            label: 'Order requested from site',
            default: 'desc',
            options: { desc: 'desc', asc: 'asc' },
        },
    ],
    login: {
        path: 'login.php',
        form: 'form.auth_form',
        inputs: {
            username: '{{ .Config.username }}',
            password: '{{ .Config.password }}',
            two_step: '{{ .Config.2facode }}',
            keeplogged: 1,
        },
        error: [{ selector: '.auth_form > .warning' }],
        test: { path: 'top10.php' },
    },
    search: {
        paths: [{ path: 'torrents.php' }],
        inputs: {
            $raw: '{{ range .Categories }}filter_cat[{{.}}]=1&{{end}}',
            searchstr: '{{ if .Query.IMDBID }}{{ else }}{{ .Keywords }}{{ end }}',
            imdbid: '{{ .Query.IMDBIDShort }}',
            tags_type: 1,
            freetorrent: '{{ if .Config.freeleech }}1{{ else }}{{ end }}',
            order_by: '{{ .Config.sort }}',
            order_way: '{{ .Config.type }}',
            action: 'advanced',
            searchsubmit: 1,
        },
        keywordsfilters: [{ name: 're_replace', args: ['(?i)(S)(\\d{1,3})$', 'season $2'] }],
        rows: { selector: 'table#torrent_table > tbody > tr.torrent' },
        fields: {
            category: {
                selector: 'a[href^="torrents.php?filter_cat"]',
                attribute: 'href',
                filters: [{ name: 'regexp', args: '\\[(\\d+)\\]' }],
            },
            download: {
                selector: 'a[title="Download"]',
                attribute: 'href',
                filters: [{ name: 'replace', args: ['\t', ' '] }],
            },
            title: {
                selector: 'div.group_info',
                remove: 'span, div.tags',
                filters: [
                    { name: 'replace', args: ['\t\t\t\t', ' '] },
                    { name: 'replace', args: [' / Free', ''] },
                    { name: 'replace', args: [' / ViE', ''] },
                    { name: 'replace', args: [' / User', ''] },
                    { name: 'replace', args: [' / Exclusive!', ''] },
                    { name: 'replace', args: [' / ↓25%', ''] },
                    { name: 'replace', args: [' / ↓50%', ''] },
                    { name: 'replace', args: [' / ↓75%', ''] },
                    { name: 'replace', args: [' / 2x 50%', ''] },
                    { name: 'replace', args: [' / 2x Free', ''] },
                    { name: 'replace', args: [' / 2x', ''] },
                    { name: 're_replace', args: [' / ', ' '] },
                    { name: 're_replace', args: ['(?i)(season )', 'S'] },
                ],
            },
            details: {
                selector: 'a.torrent_name',
                attribute: 'href',
                filters: [
                    { name: 'replace', args: ['\t', ' '] },
                    { name: 'regexp', args: '(.*)#torrent\\d+$' },
                ],
            },
            size: { selector: 'td[class="number_column nobr"]' },
            grabs: { selector: 'td[class="number_column nobr"] ~ td' },
            files: { selector: 'td:nth-child(3)' },
            seeders: { selector: 'td[class="number_column nobr"] ~ td ~ td' },
            leechers: {
                selector: 'td[class="number_column nobr"] ~ td ~ td ~ td',
            },
            date: {
                selector: 'td:nth-child(5) > span[title]',
                attribute: 'title',
                filters: [
                    { name: 'replace', args: [',', ''] },
                    { name: 'append', args: ' +07:00' },
                    { name: 'dateparse', args: 'Jan 02 2006 15:04 -07:00' },
                ],
            },
            downloadvolumefactor: {
                case: {
                    'strong.blink_me:contains("Free")': 0,
                    'strong.blink_me:contains("50")': 0.5,
                    'strong.blink_me:contains("25")': 0.75,
                    'strong.blink_me:contains("75")': 0.25,
                    '*': 1,
                },
            },
            uploadvolumefactor: {
                case: { 'strong.blink_me:contains("2x")': 2, '*': 1 },
            },
            minimumratio: { text: 0.6 },
        },
    },
    source: 'jackett',
};
